@@ -57,11 +57,10 @@ from neuralspace.constants import (
 
 console = Console()
 logger = logging.getLogger("rich")
-console = Console()
 
 
 def setup_logger(log_level: Text):
-    logging.basicConfig(level=log_level, handlers=[RichHandler()])
+    logging.basicConfig(level=log_level, handlers=[RichHandler(level=log_level)])
 
 
 def get_logo():
